@@ -54,7 +54,11 @@ var credits =
     ],
     [
         qsTr("Hatch Patterns"),
-        [ "John Hyslop",         "CELTIC-01, CELTIC-02, LATTICE-01" ],
+        [ "John Hyslop",         "CELTIC-01, CELTIC-02, CIRCLES-02, CIRCLES, " +
+                                 "EXPLOSION, HEXAGONS, HOLLY, LATTICE-01, " +
+                                 "LATTICE-02, LATTICE-03, LATTICE-04, " +
+                                 "MAZE-01, MAZE-02, QCAD-LOGO, " +
+                                 "SQUIGGLE-01, SQUIGGLE-02" ],
     ],
     [
         qsTr("Translations"),
