@@ -113,6 +113,19 @@ EcmaScriptShell.init = function(basePath) {
     }
 
     var formWidget = WidgetFactory.createWidget(basePath, "EcmaScriptShell.ui");
+
+    var frame = formWidget.findChild("Frame");
+    var p = frame.palette;
+    if (!RSettings.hasDarkGuiBackground()) {
+        // white background of command line label:
+        p.setColor(QPalette.Active, QPalette.Window, new QColor(Qt.white));
+    }
+    else {
+        p.setColor(QPalette.Active, QPalette.Window, new QColor("#1e1e1e"));
+    }
+    frame.palette = p;
+    frame.autoFillBackground = true;
+
     var teHistory = formWidget.findChild("History");
     var leCommand = formWidget.findChild("CommandEdit");
     leCommand.setHistory(RSettings.getStringListValue("EcmaScriptShell/History", []));
@@ -239,7 +252,8 @@ EcmaScriptShell.init = function(basePath) {
             var res;
             try {
                 //startTransaction();
-                res = RMainWindow.getMainWindow().eval("js", expression);
+                //res = RMainWindow.getMainWindow().eval("js", expression);
+                res = EcmaScriptShell.eval(expression);
                 //endTransaction();
 
                 // make sure input is enabled again:
@@ -330,3 +344,7 @@ EcmaScriptShell.init = function(basePath) {
 
     leCommand.clearHistory.connect(teHistory, "clear");
 };
+
+EcmaScriptShell.eval = function(expression) {
+    return RMainWindow.getMainWindow().eval("js", expression);
+}
